#version 310 es
precision mediump float;
precision highp int;

vec2 _52;

layout(location = 0) out highp vec4 _GLF_color;

void main()
{
    highp vec2 _53;
    do
    {
        if (gl_FragCoord.x != gl_FragCoord.x)
        {
            _53 = _52;
            break;
        }
        highp vec2 _51;
        _51.y = _52.y;
        _53 = _51;
        break;
    } while(false);
    _GLF_color = vec4(_53, 1.0, 1.0);
}

